<?php

$labels = array();
$labels['verifiedsender'] = 'Assinatura v&aacute;lida do dom&iacute;nio. verificado por ';
$labels['invalidsignature'] = 'Assinatura inv&aacute;lida! verificado por ';
$labels['nosignature'] = 'Sem informa&ccedil;&otilde;es de assinatura';
$labels['thirdpartysig'] = 'Sem assinatura do dono do dom&iacute;nio mas uma assinatura de terceiros presente. verificado por ';

?>
