<?php

$labels = array();
$labels['verifiedsender'] = 'Poprawna sygnatura domeny nadawczej. zweryfikowane przez ';
$labels['invalidsignature'] = 'Sygnatura nie jest poprawna! zweryfikowane przez ';
$labels['nosignature'] = 'Brak sygnatury';
$labels['thirdpartysig'] = 'Brak sygnatury domeny nadawczej. Obecna inny typ sygnatury. zweryfikowane przez ';

?>
