<?php

$labels = array();
$labels['verifiedsender'] = 'Valid signature from the author\'s domain. verified by ';
$labels['invalidsignature'] = 'Signature is not valid ! verified by ';
$labels['nosignature'] = 'No signature information';
$labels['thirdpartysig'] = 'No author\'s domain signature but a third party signature is present. verified by ';

?>
