<?php

$labels = array();
$labels['verifiedsender'] = 'Semnat in domeniul autorului. Semnatura comparata si validata de catre ';
$labels['invalidsignature'] = 'Semnatura falsa! Comparata si invalidata de catre ';
$labels['nosignature'] = 'Imposibil de comparat si validat semnatura de catre ';
$labels['thirdpartysig'] = 'Nesemnat in domeniul autorului. O semnatura este prezenta intr-o terta pozitie. Comparat si validat cu aceasta semnatura de catre ';

?>
