<?php

$labels = array();
$labels['verifiedsender'] = 'Подлинная подпись домена отправителя. Проверено ';
$labels['invalidsignature'] = 'Подпись не подлинная! Проверено ';
$labels['nosignature'] = 'Нет информации о подписи';
$labels['thirdpartysig'] = 'Нет подписи домена отправителя, но присутствует подпись другого домена. Проверено ';

?>
