<?php

$labels = array();
$labels['verifiedsender'] = 'Firma válida del dominio del autor. Verificada por ';
$labels['invalidsignature'] = '¡La firma no es válida! Verificada por ';
$labels['nosignature'] = 'Sin información de firma';
$labels['thirdpartysig'] = 'No hay firma del dominio del autor pero hay una firma de terceros. Verificada por ';

?>
