<?php
$labels = array();
$labels['verifiedsender'] = 'Firma valida dal dominio del mittente. verificato da ';
$labels['invalidsignature'] = 'La firma non è valida! verificato da ';
$labels['nosignature'] = 'Nessuna informazione sulla firma';
$labels['thirdpartysig'] = 'Nessuna firma da parte del dominio del mittente ma è presente una firma di terza parti. verificato da ';
?>