<?php

$labels = array();
$labels['verifiedsender'] = 'Signature valide provenant du domaine de l\'auteur. verifie par ';
$labels['invalidsignature'] = 'Signature invalide ! verifie par ';
$labels['nosignature'] = 'Pas d\'information de signature';
$labels['thirdpartysig'] = 'Pas de signature du domaine de l\'auteur, mais une signature tierce partie est presente. verifie par ';


?>
